@@ -211,8 +211,9 @@ class Album(Base):
                 "artists": "",
                 "artist_ids": [],
                 "year": None,
+                "timestamp": None,
                 "uri": "",
-                "tracks_count": 0,
+                "tracks_count": 1,
                 "duration": 0,
                 "mtime": 0,
                 "synced": False,
@@ -299,6 +300,15 @@ class Album(Base):
             App().albums.set_loved(self.id, loved)
             self.loved = loved
 
+    def set_uri(self, uri):
+        """
+            Set album uri
+            @param uri as str
+        """
+        if self.id >= 0:
+            App().albums.set_uri(self.id, uri)
+            self.uri = uri
+
     @property
     def title(self):
         """
@@ -361,6 +371,7 @@ class Track(Base):
                 "duration": 0,
                 "number": 0,
                 "year": None,
+                "timestamp": None,
                 "mtime": 0,
                 "mb_track_id": None}
 
