@@ -13,7 +13,6 @@
 from gi.repository import Gst, GstPbutils, GLib, Gio
 
 from re import match
-
 from gettext import gettext as _
 
 from lollypop.define import App, ENCODING
@@ -249,6 +248,9 @@ class TagReader(Discoverer):
         discname = ""
         for i in range(tags.get_tag_size("extended-comment")):
             (exists, read) = tags.get_string_index("extended-comment", i)
+            if exists and read.startswith("PART"):
+                discname = "=".join(read.split("=")[1:])
+                break
             if exists and read.startswith("DISCSUBTITLE"):
                 discname = "=".join(read.split("=")[1:])
                 break
@@ -294,24 +296,36 @@ class TagReader(Discoverer):
         """
             Return track year for tags
             @param tags as Gst.TagList
-            @return track year as int or None
+            @return year and timestamp (int, int)
         """
-        if tags is None:
-            return None
-        (exists, date) = tags.get_date_index("date", 0)
-        if not exists:
-            (exists, date) = tags.get_date_time_index("datetime", 0)
-        if exists:
-            year = date.get_year()
-        else:
-            year = None
-        return year
+        try:
+            (exists, date) = tags.get_date_index("date", 0)
+            dt = year = timestamp = None
+            if exists:
+                year = date.get_year()
+                d = Gst.DateTime.new_local_time(year, 1, 1, 0, 0, 0)
+                dt = d.to_g_date_time()
+                timestamp = dt.to_unix()
+            else:
+                (exists, date) = tags.get_date_time_index("datetime", 0)
+                if exists:
+                    dt = date.to_g_date_time()
+                    if dt is None:
+                        year = date.get_year()
+                        d = Gst.DateTime.new_local_time(year, 1, 1, 0, 0, 0)
+                        dt = d.to_g_date_time()
+                    timestamp = dt.to_unix()
+            return (year, timestamp)
+        except Exception as e:
+            error = "" if tags is None else tags.to_string()
+            Logger.error("TagReader::get_year(): %s, %s", e, error)
+        return (None, None)
 
     def get_original_year(self, tags):
         """
             Return original release year
             @param tags as Gst.TagList
-            @return year as int or None
+            @return year and timestamp (int, int)
         """
         def get_id3():
             try:
@@ -328,10 +342,12 @@ class TagReader(Discoverer):
                     string = m.data.decode("utf-8")
                     if string.startswith("TDOR"):
                         split = string.split("\x00")
-                        return int(split[-1][:4])
+                        date = split[-1]
+                        datetime = GLib.DateTime.new_from_iso8601(date, None)
+                        return (datetime.year(), datetime.to_unix())
             except:
                 pass
-            return None
+            return (None, None)
 
         def get_ogg():
             try:
@@ -342,18 +358,19 @@ class TagReader(Discoverer):
                         i)
                     if not exists or not sample.startswith("ORIGINALDATE="):
                         continue
-                    # ORIGINALDATE=1999-03-10 => Only year
-                    return int(sample[13:][:4])
+                    date = sample[13:]
+                    datetime = GLib.DateTime.new_from_iso8601(date, None)
+                    return (datetime.year(), datetime.to_unix())
             except:
                 pass
             return None
 
         if tags is None:
             return None
-        year = get_id3()
-        if year is None:
-            year = get_ogg()
-        return year
+        values = get_id3()
+        if values is None:
+            values = get_ogg()
+        return values
 
     def get_lyrics(self, tags):
         """
@@ -536,10 +553,7 @@ class TagReader(Discoverer):
         """
         f = Gio.File.new_for_uri(uri)
         d = f.get_parent()
-        if d is not None:
-            parent_uri = d.get_uri()
-        else:
-            parent_uri = ""
+        parent_uri = "/" if d is None else d.get_uri()
         new = False
         album_id = App().albums.get_id(album_name, mb_album_id, artist_ids)
         if album_id is None:
