@@ -16,18 +16,26 @@ from gettext import gettext as _
 from random import choice
 
 from lollypop.widgets_album import AlbumWidget
+from lollypop.art import AlbumArtHelper
 from lollypop.pop_menu import AlbumMenu
 from lollypop.define import App, ArtSize, Shuffle
 
 
-class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
+class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget, AlbumArtHelper):
     """
         Album widget showing cover, artist and title
     """
     __gsignals__ = {
+        "populated": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "overlayed": (GObject.SignalFlags.RUN_FIRST, None, (bool,))
     }
 
+    ctx = App().window.get_pango_context()
+    layout = Pango.Layout.new(ctx)
+    layout.set_text("a", 1)
+    # * 2 => two labels
+    LABEL_HEIGHT = int(layout.get_pixel_size()[1])
+
     def __init__(self, album, genre_ids, artist_ids):
         """
             Init simple album widget
@@ -37,68 +45,45 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         """
         # We do not use Gtk.Builder for speed reasons
         Gtk.FlowBoxChild.__init__(self)
-        self.set_size_request(ArtSize.BIG, ArtSize.BIG)
+        self.set_size_request(ArtSize.BIG, ArtSize.BIG + self.LABEL_HEIGHT)
         self.get_style_context().add_class("loading")
-        AlbumWidget.__init__(self, album, genre_ids,
-                             artist_ids, ArtSize.BIG)
+        AlbumArtHelper.__init__(self)
+        AlbumWidget.__init__(self, album, genre_ids, artist_ids)
 
     def populate(self):
         """
             Populate widget content
         """
+        AlbumArtHelper.populate(self, ArtSize.BIG, "cover-frame")
         self.get_style_context().remove_class("loading")
         self._widget = Gtk.EventBox()
         grid = Gtk.Grid()
         grid.set_orientation(Gtk.Orientation.VERTICAL)
-        self._artwork = Gtk.Image()
-        self._artwork.set_property("halign", Gtk.Align.CENTER)
-        self._artwork.get_style_context().add_class("cover-frame")
-        self.__title_label = Gtk.Label()
-        self.__title_label.set_ellipsize(Pango.EllipsizeMode.END)
-        self.__title_label.set_property("halign", Gtk.Align.CENTER)
-        self.__title_label.set_markup("<b>" +
-                                      GLib.markup_escape_text(
-                                          self._album.name) +
-                                      "</b>")
-        self.__artist_label = Gtk.Label()
-        self.__artist_label.set_ellipsize(Pango.EllipsizeMode.END)
-        self.__artist_label.set_property("halign", Gtk.Align.CENTER)
-        self.__artist_label.set_text(", ".join(self._album.artists))
-        self.__artist_label.get_style_context().add_class("dim-label")
-        artist_eventbox = Gtk.EventBox()
-        artist_eventbox.add(self.__artist_label)
-        artist_eventbox.connect("realize", self._on_eventbox_realize)
-        artist_eventbox.connect("button-press-event",
-                                self.__on_artist_button_press)
-        artist_eventbox.show()
-        self._widget.set_property("has-tooltip", True)
-        self._widget.connect("query-tooltip", self._on_query_tooltip)
+        self.__label = Gtk.Label()
+        self.__label.set_justify(Gtk.Justification.CENTER)
+        self.__label.set_ellipsize(Pango.EllipsizeMode.END)
+        self.__label.set_property("halign", Gtk.Align.CENTER)
+        album_name = GLib.markup_escape_text(self._album.name)
+        artist_name = GLib.markup_escape_text(", ".join(self._album.artists))
+        self.__label.set_markup("<b>%s</b>\n<span alpha='40000'>%s</span>" %
+                                (album_name, artist_name))
+        eventbox = Gtk.EventBox()
+        eventbox.add(self.__label)
+        eventbox.set_property("has-tooltip", True)
+        eventbox.connect("query-tooltip", self._on_query_tooltip)
+        eventbox.connect("realize", self._on_eventbox_realize)
+        eventbox.connect("button-press-event",
+                         self.__on_artist_button_press)
+        eventbox.show()
         self._widget.add(grid)
         self.__overlay = Gtk.Overlay.new()
-        self.__overlay.set_property("halign", Gtk.Align.CENTER)
-        self.__overlay.set_property("valign", Gtk.Align.CENTER)
-        self.__overlay_grid = Gtk.Grid()
-        self.__overlay_grid.set_row_spacing(6)
-        self.__overlay_grid.set_margin_top(6)
-        self.__overlay_grid.set_margin_bottom(6)
-        self.__overlay_grid.set_margin_start(6)
-        self.__overlay_grid.set_margin_end(6)
         self.__overlay.add(self._artwork)
-        self.__overlay.add_overlay(self.__overlay_grid)
-        color = Gtk.Grid()
-        color.set_property("halign", Gtk.Align.CENTER)
-        color.set_property("valign", Gtk.Align.CENTER)
-        color.get_style_context().add_class("white")
-        color.add(self.__overlay)
-        grid.add(color)
-        grid.add(self.__title_label)
-        grid.add(artist_eventbox)
+        self.__overlay_grid = None
+        grid.add(self.__overlay)
+        grid.add(eventbox)
         self.add(self._widget)
-        self.set_artwork()
+        AlbumArtHelper.set_artwork(self)
         self.set_selection()
-        self._widget.set_property("halign", Gtk.Align.CENTER)
-        self._widget.set_property("valign", Gtk.Align.CENTER)
-        self.show_all()
         self._widget.connect("enter-notify-event", self._on_enter_notify)
         self._widget.connect("leave-notify-event", self._on_leave_notify)
         self._widget.connect("button-press-event", self.__on_button_press)
@@ -171,25 +156,24 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
                                         self._on_action_press_event)
             self._action1_button = Gtk.Image.new()
             self._action1_button.set_opacity(0)
-            self.__overlay_grid.set_orientation(self._overlay_orientation)
-            if self._overlay_orientation == Gtk.Orientation.VERTICAL:
-                self._play_event.set_hexpand(False)
-                self._play_event.set_vexpand(True)
-                self._play_event.set_property("halign", Gtk.Align.END)
-                self._play_event.set_property("valign", Gtk.Align.START)
-                self.__overlay_grid.set_property("valign", Gtk.Align.FILL)
-                self.__overlay_grid.set_property("halign", Gtk.Align.END)
-            else:
-                self._play_event.set_hexpand(True)
-                self._play_event.set_vexpand(False)
-                self._play_event.set_property("halign", Gtk.Align.START)
-                self._play_event.set_property("valign", Gtk.Align.END)
-                self.__overlay_grid.set_property("halign", Gtk.Align.FILL)
-                self.__overlay_grid.set_property("valign", Gtk.Align.END)
+            self._play_event.set_hexpand(True)
+            self._play_event.set_vexpand(False)
+            self._play_event.set_property("halign", Gtk.Align.START)
+            self._play_event.set_property("valign", Gtk.Align.END)
             self._play_event.add(self._play_button)
             self._play_all_event.add(self._play_all_button)
             self._action2_event.add(self._action2_button)
             self._action1_event.add(self._action1_button)
+            if self.__overlay_grid is None:
+                self.__overlay_grid = Gtk.Grid()
+                self.__overlay_grid.set_row_spacing(6)
+                self.__overlay_grid.set_margin_top(6)
+                self.__overlay_grid.set_margin_bottom(6)
+                self.__overlay_grid.set_margin_start(6)
+                self.__overlay_grid.set_margin_end(6)
+                self.__overlay_grid.set_property("halign", Gtk.Align.FILL)
+                self.__overlay_grid.set_property("valign", Gtk.Align.END)
+                self.__overlay.add_overlay(self.__overlay_grid)
             self.__overlay_grid.add(self._play_event)
             self.__overlay_grid.add(self._play_all_event)
             self.__overlay_grid.add(self._action1_event)
@@ -244,16 +228,11 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             track = choice(self._album.tracks)
         else:
             track = self._album.tracks[0]
-        if App().window.container.view.filtered:
-            App().player.clear_albums()
-            # Here we need to get ids from parent as view may be filtered
-            for child in self.get_parent().get_children():
-                if not child.filtered:
-                    App().player.add_album(child.album)
-        else:
-            App().player.play_albums(track,
-                                     self._album.genre_ids,
-                                     self._album.artist_ids)
+        App().player.clear_albums()
+        for child in self.get_parent().get_children():
+            if not child.filtered:
+                App().player.add_album(child.album)
+        App().player.load(track)
         return True
 
     def _on_query_tooltip(self, eventbox, x, y, keyboard, tooltip):
@@ -265,20 +244,11 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             @param keyboard as bool
             @param tooltip as Gtk.Tooltip
         """
-        eventbox.set_tooltip_text("")
-        for widget in [self.__title_label, self.__artist_label]:
-            layout = widget.get_layout()
-            if layout.is_ellipsized():
-                artist_text = self.__artist_label.get_text()
-                if artist_text:
-                    text = "<b>%s</b> - %s" % (
-                        GLib.markup_escape_text(artist_text),
-                        GLib.markup_escape_text(self.__title_label.get_text()))
-                else:
-                    text = GLib.markup_escape_text(
-                        self.__title_label.get_text())
-                eventbox.set_tooltip_markup(text)
-                break
+        layout = self.__label.get_layout()
+        if layout.is_ellipsized():
+            markup = self.__label.get_label()
+            tooltip.set_markup(markup)
+            return True
 
     def __on_button_press(self, eventbox, event):
         """
